import NotebookAdapter from './NotebookAdapter';
import { ReactPortal } from 'react';
import { INotebookModel } from '@jupyterlab/notebook';
import * as nbformat from '@jupyterlab/nbformat';
import { Cell, ICellModel } from '@jupyterlab/cells';
import { NotebookChange } from '@jupyter/ydoc';
import { Kernel as JupyterKernel } from '@jupyterlab/services';
import Kernel from '../../jupyter/kernel/Kernel';
export type PortalDisplay = {
    portal: ReactPortal;
    pinned: boolean;
};
export type INotebookState = {
    model?: INotebookModel;
    adapter?: NotebookAdapter;
    saveRequest?: Date;
    activeCell?: Cell<ICellModel>;
    kernelStatus?: JupyterKernel.Status;
    notebookChange?: NotebookChange;
    portals: ReactPortal[];
    portalDisplay?: PortalDisplay;
};
export interface INotebooksState {
    notebooks: Map<string, INotebookState>;
}
type UpdateId = {
    id: string;
    partialState: Partial<INotebookState>;
};
type NotebookChangeId = {
    id: string;
    notebookChange: NotebookChange;
};
type NotebookModelId = {
    id: string;
    notebookModel: INotebookModel;
};
type CellModelId = {
    id: string;
    cellModel?: Cell<ICellModel>;
};
type KernelStatusMutation = {
    id: string;
    kernelStatus: JupyterKernel.Status;
};
type KernelChangeMutation = {
    id: string;
    kernel: Kernel;
};
type ReactPortalsMutation = {
    id: string;
    portals: ReactPortal[];
};
type PortalDisplayMutation = {
    id: string;
    portalDisplay: PortalDisplay | undefined;
};
type DateMutation = {
    id: string;
    date: Date | undefined;
};
type CellMutation = {
    id: string;
    cellType: nbformat.CellType;
    source?: string;
};
export type NotebookState = INotebooksState & {
    setNotebooks: (notebooks: Map<string, INotebookState>) => void;
    selectNotebook: (id: string) => INotebookState | undefined;
    selectNotebookModel: (id: string) => {
        model: INotebookModel | undefined;
        changed: any;
    } | undefined;
    selectKernelStatus: (id: string) => string | undefined;
    selectActiveCell: (id: string) => Cell<ICellModel> | undefined;
    selectNotebookPortals: (id: string) => React.ReactPortal[] | undefined;
    selectSaveRequest: (id: string) => Date | undefined;
    selectNotebookPortalDisplay: (id: string) => PortalDisplay | undefined;
    run: (id: string) => void;
    runAll: (id: string) => void;
    interrupt: (id: string) => void;
    insertAbove: (mutation: CellMutation) => void;
    insertBelow: (mutation: CellMutation) => void;
    delete: (id: string) => void;
    changeCellType: (mutation: CellMutation) => void;
    save: (mutation: DateMutation) => void;
    reset: () => void;
    update: (update: UpdateId) => void;
    activeCellChange: (cellModelId: CellModelId) => void;
    modelChange: (notebookModelId: NotebookModelId) => void;
    notebookChange: (notebookChangeId: NotebookChangeId) => void;
    kernelStatusChanged: (kernelStatusId: KernelStatusMutation) => void;
    changeKernel: (kernelChange: KernelChangeMutation) => void;
    addPortals: (portalsId: ReactPortalsMutation) => void;
    dispose: (id: string) => void;
    setPortals: (portalsId: ReactPortalsMutation) => void;
    setPortalDisplay: (portalDisplayId: PortalDisplayMutation) => void;
};
export declare const notebookStore: import("zustand").StoreApi<NotebookState>;
export declare function useNotebookStore(): NotebookState;
export declare function useNotebookStore<T>(selector: (state: NotebookState) => T): T;
export default useNotebookStore;
