/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createStore } from 'zustand/vanilla';
import { useStore } from 'zustand';
export const outputsStore = createStore((set, get) => ({
    outputs: new Map(),
    getAdapter: (id) => {
        return get().outputs.get(id)?.adapter;
    },
    getInput: (id) => {
        return get().outputs.get(id)?.input;
    },
    getModel: (id) => {
        return get().outputs.get(id)?.model;
    },
    getDataset: (id) => {
        return get().outputs.get(id)?.dataset;
    },
    getExecuteRequest: (id) => {
        return get().outputs.get(id)?.code;
    },
    getGradeSuccess: (id) => {
        return get().outputs.get(id)?.gradeSuccess;
    },
    setOutputs: (id, outputs) => set((state) => ({ outputs })),
    setAdapter: (id, adapter) => {
        const outputs = get().outputs;
        const d = outputs.get(id);
        if (d) {
            d.adapter = adapter;
        }
        else {
            outputs.set(id, { adapter });
        }
        set((state) => ({ outputs }));
    },
    setDataset: (id, dataset) => {
        const outputs = get().outputs;
        const d = outputs.get(id);
        if (d) {
            d.dataset = dataset;
        }
        else {
            outputs.set(id, { dataset });
        }
        set((state) => ({ outputs }));
    },
    setExecuteRequest: (id, code) => {
        const outputs = get().outputs;
        const e = outputs.get(id);
        if (e) {
            e.code = code;
        }
        else {
            outputs.set(id, { code });
        }
        set((state) => ({ outputs }));
    },
    setModel: (id, model) => {
        const outputs = get().outputs;
        const e = outputs.get(id);
        if (e) {
            e.model = model;
        }
        else {
            outputs.set(id, { model });
        }
        set((state) => ({ outputs }));
    },
    setInput: (id, input) => {
        const outputs = get().outputs;
        const e = outputs.get(id);
        if (e) {
            e.input = input;
        }
        else {
            outputs.set(id, { input });
        }
        set((state) => ({ outputs }));
    },
    setGradeSuccess: (id, gradeSuccess) => {
        const outputs = get().outputs;
        const e = outputs.get(id);
        if (e) {
            e.gradeSuccess = gradeSuccess;
        }
        else {
            outputs.set(id, { gradeSuccess });
        }
        set((state) => ({ outputs }));
    },
}));
export function useOutputsStore(selector) {
    return useStore(outputsStore, selector);
}
export default useOutputsStore;
//# sourceMappingURL=OutputState.js.map