import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { BaseStyles, Box, ThemeProvider, theme as primerTheme, } from '@primer/react';
import { useMemo } from 'react';
import { ErrorBoundary } from 'react-error-boundary';
import { loadJupyterConfig } from './JupyterConfig';
import { JupyterContextProvider } from './JupyterContext';
import JupyterLabCss from './lab/JupyterLabCss';
/**
 * The component to be used as fallback in case of error.
 */
const ErrorFallback = ({ error, resetErrorBoundary }) => {
    return (_jsxs("div", { role: "alert", children: [_jsx("p", { children: "Oops, something went wrong." }), _jsx("pre", { children: error.message }), _jsx("div", { style: { visibility: 'hidden' }, children: _jsx("button", { onClick: resetErrorBoundary, children: "Try again" }) })] }));
};
/**
 * The Jupyter context. This handles the needed initialization
 * and ensure the Primer theme providers is available.
 */
export const Jupyter = (props) => {
    const { children, collaborative, colorMode = 'light', defaultKernelName, disableCssLoading = false, initCode = '', jupyterServerUrl, jupyterServerToken, lite, startDefaultKernel, skeleton, terminals = false, theme = primerTheme, useRunningKernelId, useRunningKernelIndex, } = props;
    const config = useMemo(() => {
        return loadJupyterConfig({
            collaborative,
            jupyterServerUrl,
            jupyterServerToken,
            lite,
            terminals,
        });
    }, [
        collaborative,
        jupyterServerUrl,
        jupyterServerToken,
        lite,
        terminals,
    ]);
    return (_jsx(ErrorBoundary, { FallbackComponent: ErrorFallback, onReset: () => {
            console.log('Error Boundary reset has been invoked...');
        }, children: _jsx(ThemeProvider, { theme: theme, colorMode: colorMode === 'light' ? 'day' : 'night', dayScheme: "light", nightScheme: "dark", children: _jsx(BaseStyles, { children: _jsxs(Box, { color: "fg.default", bg: "canvas.default", children: [!config.insideJupyterLab && !disableCssLoading && (_jsx(JupyterLabCss, { colorMode: colorMode })), _jsx(JupyterContextProvider, { collaborative: collaborative, defaultKernelName: defaultKernelName, initCode: initCode, lite: lite, skeleton: skeleton, startDefaultKernel: startDefaultKernel, useRunningKernelId: useRunningKernelId, useRunningKernelIndex: useRunningKernelIndex, children: children })] }) }) }) }));
};
export default Jupyter;
//# sourceMappingURL=Jupyter.js.map